
.. _Aergo: http://github.com/aergoio/aergo
.. _HeraPy: http://github.com/aergoio/herapy

How to use HeraPy
=================

You can easily start to use HeraPy_ following the ":doc:`getting started <../getting_started>`" document.

After installing HeraPy_ and before writing any code, calling up the HeraPy_ module should be first.

.. code-block:: python
   :linenos:

    import aergo.herapy as herapy


And then, now, you would find out how to use HeraPy_ in depth under this document.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   connect
   .. how_to_blockchain
   .. how_to_account
   .. how_to_transaction
   .. how_to_smart_contract

